import { aws_ec2 as ec2, aws_lambda as lambda, aws_rds as rds, aws_secretsmanager as secretsmanager } from "aws-cdk-lib";
import { IDomainName } from "@aws-cdk/aws-apigatewayv2-alpha";
import { Construct } from "constructs";
import { CustomLambdaFunctionProps } from "../utils";
export declare class TiPgApiLambda extends Construct {
    readonly url: string;
    tiPgLambdaFunction: lambda.Function;
    constructor(scope: Construct, id: string, props: TiPgApiLambdaProps);
}
export interface TiPgApiLambdaProps {
    /**
     * VPC into which the lambda should be deployed.
     */
    readonly vpc?: ec2.IVpc;
    /**
     * RDS Instance with installed pgSTAC or pgbouncer server.
     */
    readonly db: rds.IDatabaseInstance | ec2.IInstance;
    /**
     * Subnet into which the lambda should be deployed.
     */
    readonly subnetSelection?: ec2.SubnetSelection;
    /**
     * Secret containing connection information for pgSTAC database.
     */
    readonly dbSecret: secretsmanager.ISecret;
    /**
     * Customized environment variables to send to titiler-pgstac runtime.
     */
    readonly apiEnv?: Record<string, string>;
    /**
     * Custom Domain Name for tipg API. If defined, will create the
     * domain name and integrate it with the tipg API.
     *
     * @default - undefined
     */
    readonly tipgApiDomainName?: IDomainName;
    /**
     * Can be used to override the default lambda function properties.
     *
     * @default - defined in the construct.
     */
    readonly lambdaFunctionOptions?: CustomLambdaFunctionProps;
}
